﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

/// <summary>
/// Simple bullet object with collision reaction
/// </summary>
public class Bullet : MonoBehaviour
{
    // The speed of the bullet force
    public float speed = 50.0f;
    private new Rigidbody rigidbody;

    private void Awake()
    {
        rigidbody = GetComponent<Rigidbody>();
    }
    /// <summary>
    /// Called method when the gun fires
    /// </summary>
    public void Fire(Vector3 forward)
    {
        // Apply force to rigidbody so the bullet starts moving in appropriate direction
        rigidbody.AddForce(forward * speed);
        
        // Destroy after 5 seconds
        Destroy(gameObject, 5.0f);
    }
    /// <summary>
    /// Called when this object collides with another
    /// </summary>
    private void OnCollisionEnter(Collision other) 
    {
        Gun gun = null;
     
        // Ignore collision with gun
        if(other.gameObject.TryGetComponent<Gun>(out gun))
            return;
        
        IHittable hittable = null;

        // The object of the collider implements the interface IHittable
        if(other.transform.TryGetComponent<IHittable>(out hittable))
            hittable.Hit(transform, rigidbody.velocity.magnitude);

        // Destroy after 0.1 seconds 
        Destroy(gameObject, 0.1f);
    }
}
