﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.XR.Interaction.Toolkit;

/// <summary>
/// Simple grabbable gun that fires when activating
/// </summary>
public class Gun : XRGrabInteractable
{
    public GameObject bulletPrefab;
    public Transform bulletTransform;

    /// <summary>
    /// Called upon enabling the object
    /// </summary>
    protected override void OnEnable()
    {
        // Activate button event
        activated.AddListener(Shoot);
        base.OnEnable();
    }
    /// <summary>
    /// Called upon disabling the object
    /// </summary>
    protected override void OnDisable()
    {
        activated.RemoveListener(Shoot);
        base.OnDisable();
    }
    /// <summary>
    /// Shoots a bullet from the gun and applies short haptics on the controller
    /// </summary>
    private void Shoot(ActivateEventArgs args)
    {
        GameObject bulletObject = Instantiate(bulletPrefab, bulletTransform.position, bulletTransform.rotation);
        Bullet bullet = null;
        
        // Fire the bullet
        if(bulletObject.TryGetComponent<Bullet>(out bullet))
            bullet.Fire(bulletTransform.forward);

        // Haptics feature on interactor 
        if(args.interactor is XRDirectInteractor hand)
            hand.xrController.SendHapticImpulse(1.0f, 0.2f);
    }
}
